==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/ffmpeg/translations/ffmpeg_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="192"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>Über FFmpeg-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="194"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Qmmp FFmpeg-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="204"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="121"/>
        <source>FFmpeg Plugin</source>
        <translation>FFmpeg-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="123"/>
        <source>FFmpeg Formats</source>
        <translation>FFmpeg-Formate</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="196"/>
        <source>Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6</source>
        <translation>Kompiliert gegen libavformat-%1.%2.%3 und libavcodec-%4.%5.%6</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="59"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="60"/>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="60"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="61"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="61"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
        <source>Sample rate</source>
        <translation>Abtastrate</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="73"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>Formate</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation>Windows Media Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio</source>
        <translation>Monkey&apos;s Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation>True Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ALAC (Apple Lossless Audio Codec)</source>
        <translation>ALAC (Apple Lossless Audio Codec)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>ADTS AAC</source>
        <translation>ADTS AAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>MPEG-4 AAC</source>
        <translation>MPEG-4 AAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>RealAudio 1.0/2.0</source>
        <translation>RealAudio 1.0/2.0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Shorten</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>Einstellungen FFmpeg-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation>MP3 (MPEG Audio Layer 3)</translation>
    </message>
</context>
</TS>

==> qmmp_0.5.1.orig.tar.gz: qmmp-0.5.1/src/plugins/Input/ffmpeg/translations/ffmpeg_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="187"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>Über FFmpeg-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="189"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Qmmp FFmpeg-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="199"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="84"/>
        <source>FFmpeg Plugin</source>
        <translation>FFmpeg-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="86"/>
        <source>FFmpeg Formats</source>
        <translation>FFmpeg-Formate</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="191"/>
        <source>Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6</source>
        <translation>Kompiliert gegen libavformat-%1.%2.%3 und libavcodec-%4.%5.%6</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="48"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="49"/>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="49"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="50"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="50"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
        <source>Sample rate</source>
        <translation>Abtastrate</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="67"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>Formate</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation>Windows Media Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio</source>
        <translation>Monkey&apos;s Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation>True Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation>ADTS AAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation>RealAudio 1.0/2.0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translatorcomment>Name eines Dateiformats</translatorcomment>
        <translation>Shorten</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>AC-3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>Einstellungen FFmpeg-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation>MP3 (MPEG Audio Layer 3)</translation>
    </message>
</context>
</TS>
